.. Mendel,MD documentation master file, created by
   sphinx-quickstart on Thu Apr 13 20:08:17 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Mendel,MD's documentation!
=====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   annotation
   clinical_cases
   filter_analysis
   extension


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
